@@ -1,6 +1,5 @@
 """Handle Mongo operations."""
 
-from nislmigrate.logs.migration_error import MigrationError
 import os
 import logging
 from typing import Callable, List, Dict, Optional, Any
@@ -14,17 +13,16 @@ from pymongo.database import Database
 
 from nislmigrate.facades.mongo_configuration import MongoConfiguration
 from nislmigrate.facades.process_facade import ProcessFacade, BackgroundProcess, ProcessError
+from nislmigrate.logs.migration_error import MigrationError
+from nislmigrate.utility.paths import get_ni_application_data_directory_path, get_ni_shared_directory_64_path
 
 MONGO_CONFIGURATION_PATH: str = os.path.join(
-    str(os.environ.get('ProgramData')),
-    'National Instruments',
+    get_ni_application_data_directory_path(),
     'Skyline',
     'NoSqlDatabase',
     'mongodb.conf')
 MONGO_BINARIES_DIRECTORY: str = os.path.join(
-    str(os.environ.get('ProgramW6432')),
-    'National Instruments',
-    'Shared',
+    get_ni_shared_directory_64_path(),
     'Skyline',
     'NoSqlDatabase',
     'bin')
